# These must be the same as in the PostgreSQL RPM:
%{!?%packagename:%define packagename rh-postgresql94-postgresql}
%{!?shortname:%define shortname pgsql}
%{!?%majorversion:%define majorversion 9.4}
%{!?%shortmajorversion:%define shortmajorversion 94}

%{!?pgbaseinstdir:%define pgbaseinstdir /opt/rh/rh-postgresql94/root/usr/}

# The version of the underlying PostgreSQL release we require, coresponding to
# Version: in the Pg RPM, and optionally the Release too.
%{!?required_pg:%define required_pg 9.4.4}

# The pglogical output plugin version we require
%{!?required_pglogical_output:%define required_pglogical_output 1.1.0}

# If you're building a git snapshot, you must set the githash macro so that
# the spec file will locate the correct tarball. If you're building a tagged
# final release you must instead set the gittag macro.
#
#% define githash 1deadbe
# -or-
#% define gittag something
#
%define gittag REL1_1_2

# If you --define a githash or set it in a macro, adds it to the Release field:
%{?githash:%define releasegitsuffix _git%{githash}}

Name:		%{packagename}-pglogical
Version:	1.1.2
Release:	1_2ndQuadrant%{?releasegitsuffix}%{?dist}
Summary:	pglogical - trigger-free streaming logical replication

Group:		Applications/Databases
License:	PostgreSQL
URL:		http://2ndquadrant.com/pglogical
Source0:        pglogical-%{version}.tar.bz2
Source1:        pglogical-%{version}.tar.bz2.md5

BuildRequires:		%{packagename}-devel%{?_isa} >= %{required_pg}
BuildRequires:		%{packagename}-static%{?_isa} >= %{required_pg}
Requires:		%{packagename}%{?_isa} >= %{required_pg}
Requires:		%{packagename}-server%{?_isa} >= %{required_pg}
Requires:		%{packagename}-contrib%{?_isa} >= %{required_pg}

BuildRequires:		%{packagename}-pglogical-output >= %{required_pglogical_output}
Requires:		%{packagename}-pglogical-output >= %{required_pglogical_output}

# These should match those in the PostgreSQL spec, as they're headers
# PostgreSQL exposes via includes in its own public headers, and/or or that
# pg_config will emit linker options to link to.
#
# These should actually be Requires: dependencies of postgresql94-devel, but
# they aren't; see http://www.postgresql.org/message-id/547C0032.7040309@2ndquadrant.com
#
BuildRequires:  openssl-devel
BuildRequires:  gettext >= 0.10.35
BuildRequires:  libxml2-devel libxslt-devel
BuildRequires:  pam-devel
BuildRequires:  readline-devel
BuildRequires:  zlib-devel >= 1.0.4

%description
Ths package installs the pglogical plugin that provides logical streaming
replication for PostgreSQL using a publish/subscribe model.  It can be used for
upgrades between major versions, full database replication, selective
replication, & gathering/merging data from multiple upstream servers.

pglogical is developed, maintained, and supported by 2ndQuadrant
(http://2ndquadrant.com).

This package is built for PostgreSQL %{packagename}%{shortmajorversion}
from http://yum.postgresql.org/

%prep
# Enforce that you must set gittag or githash
%if "%{?gittag}" != "" && "%{?githash}" != ""
  %{error:Both %%gittag and %%githash set, bad spec file configuration. See README.md}
%else
  %if "%{?gittag}" == "" && "%{?githash}" == ""
    %{error:No %%gittag or %%githash set, bad spec file configuration. See README.md}
  %endif
%endif

%setup -q -n pglogical-%{version}%{?releasegitsuffix}

%build
%{?scl:scl enable rh-postgresql94 - << \EOF}
export PATH=%{pgbaseinstdir}/bin:$PATH
make USE_PGXS=1 -s %{?_smp_mflags}
%{?scl:EOF}

%install
%{?scl:scl enable rh-postgresql94 - << \EOF}
export PATH=%{pgbaseinstdir}/bin:$PATH
make USE_PGXS=1 DESTDIR=%{buildroot} install
%{?scl:EOF}

mkdir -p %{buildroot}/usr/share/doc/%{packagename}%{shortmajorversion}-pglogical
cp README.md %{buildroot}/usr/share/doc/%{packagename}%{shortmajorversion}-pglogical/

%files
%{pgbaseinstdir}/lib64/pgsql/pglogical.so
%{pgbaseinstdir}/share/pgsql/extension/pglogical--1.0.0.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical--1.0.1.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical--1.1.0.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical--1.1.1.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical--1.1.2.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical--1.0.0--1.0.1.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical--1.0.0--1.1.0.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical--1.0.1--1.1.0.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical--1.1.0--1.1.1.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical--1.1.1--1.1.2.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical--1.1.0--1.1.2.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical.control
%if "%{shortmajorversion}" == "94"
%{pgbaseinstdir}/share/pgsql/extension/pglogical_origin--1.0.0.sql
%{pgbaseinstdir}/share/pgsql/extension/pglogical_origin.control
%{pgbaseinstdir}/bin/pglogical_dump
%endif
%{pgbaseinstdir}/bin/pglogical_create_subscriber
/usr/share/doc/%{packagename}%{shortmajorversion}-pglogical/README.md


%changelog
* Thu Jun 09 2016 Craig Ringer <craig.ringer@2ndquadrant.com> 1.1.2-1_2ndQuadrant
- Bug fixes for 1.1.0 stable series

* Tue Dec 22 2015 Craig Ringer <craig@2ndquadrant.com> 1.0.0-1_2ndQuadrant
- First cut pglogical package
